#
# spec file for package python-publicsuffixlist
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-publicsuffixlist
Version:        1.0.2.20241120
Release:        1.1
Summary:        Public suffix list implementaion in Python
License:        MPL-2.0
URL:            https://github.com/ko-zu/psl
Source:         https://files.pythonhosted.org/packages/source/p/publicsuffixlist/publicsuffixlist-%{version}.tar.gz
# PATCH-FIX-OPENSUSE change_psl_location.patch -- use list from publicsuffix package
Patch0:         change_psl_location.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION tests
BuildRequires:  publicsuffix
# /SECTION
Requires:       publicsuffix
Recommends:     python-requests
BuildArch:      noarch

%python_subpackages

%description
Parser implementation for the Public Suffix List <https://publicsuffix.org/> in Python.

Support for IDN (unicode or punycoded).

%prep
%autosetup -p1 -n publicsuffixlist-%{version}
sed -i '/public_suffix_list\.dat/ d' setup.py
rm publicsuffixlist/update.py

%build
%pyproject_wheel

%install
%pyproject_install
rm %{buildroot}%{_bindir}/publicsuffixlist-download
%{python_expand rm -f %{buildroot}%{$python_sitelib}/publicsuffixlist/test* %{buildroot}%{$python_sitelib}/publicsuffixlist/__pycache__/test*
%fdupes %{buildroot}%{$python_sitelib}
}

%check
%pyunittest discover -v

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/publicsuffixlist
%{python_sitelib}/publicsuffixlist-%{version}.dist-info

%changelog
* Wed Nov 20 2024 Dirk Müller <dmueller@suse.com>
- update to 1.0.2.20241120:
  * various toplevel domain updates
* Thu Nov  7 2024 Dirk Müller <dmueller@suse.com>
- update to 1.0.2.20241107:
  * various toplevel domain updates
* Fri Oct 18 2024 Dirk Müller <dmueller@suse.com>
- update to 1.0.2.20241018:
  * various toplevel domain updates
* Mon Sep 30 2024 Dirk Müller <dmueller@suse.com>
- update to 1.0.2.20240927:
  * various toplevel domain updates
* Wed Sep  4 2024 Sebastian Wagner <sebix@sebix.at>
- update to version 1.0.2:
  - Use @typing.overload to indicate str-to-str domain input/output. #32.
  - Address deprecation of ByteString in python 3.14.
- update to version 1.0.1:
  - Fix internal logic where domain name passed as a tuple of bytes, that contains
  UTF-8 encoded non-ascii chars, unintentionally matched PSL. Fixes #31.
- update to version 1.0.0:
  - This version drops support for Python 2.x and 3.4.
  - The internal logic has been slightly changed to address conflicting evaluation
  rules between the PSL wiki and the test data.
  As with versions before 1.0.0, this module assumes that wildcards have
  implicit public declarations on the wildcard root.
  - With the minimum Python version changed to 3.5, type annotations have
  been added to exposed API methods to clarify expected input types.
  For example, psl.publicsuffix() now accepts `str` or `Tuple[bytes, ...]`.
  - Add tuple of bytes style input
  - Add keep_case keyword argument
  - Accept trailing dot
  - Migrate CI to GitHub Actions
* Sun Apr 21 2024 Dirk Müller <dmueller@suse.com>
- update to 0.10.0.20240420:
  * various toplevel domain updates
* Mon Apr 15 2024 Dirk Müller <dmueller@suse.com>
- update to 0.10.0.20240412:
  * various toplevel domain updates
* Tue Mar 19 2024 Dirk Müller <dmueller@suse.com>
- update to 0.10.0.20240312:
  * various toplevel domain updates
* Fri Mar  1 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to  0.10.0.20240214:
  * various toplevel domain updates
- Switch to autosetup and pyproject macros.
- No more greedy globs in %%files.
* Tue Jan  9 2024 Dirk Müller <dmueller@suse.com>
- update to 0.10.0.20240108:
  * various toplevel domain updates
* Wed Dec 27 2023 Dirk Müller <dmueller@suse.com>
- update to 0.10.0.20231214:
  * various toplevel domain updates
* Tue Nov 14 2023 Dirk Müller <dmueller@suse.com>
- Update to version 0.10.0.20231109:
  * switch to automatically generated and uploaded to PyPI
  release.
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.9.1
  * Use underscore in setup.cfg format
* Tue Oct  4 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version to 0.9.0
  * Update PSL
  * Add tests for accept_unknown as method argument
  * Fix using a non-default accept_unknown in privatesuffix()
- Update to version to 0.8.0
  * Update PSL
  * Ensure privateparts returns lowercase labels
  * Fix is_public for upper case input
  * Fix lowercase for TLD only suffix
  * Update PSL
  * Update PSL
  * Update PSL
  * Increment version
  * Update PSL
  * Add testcase for wildcard match
  * Update test data and readme link
  * Update PSL
  * Update PSL
  * Migrate CI to travis-ci.com
  * Update PSL
  * Update PSL
  * Update PSL
  * Update PSL
* Thu Dec 16 2021 Sebastian Wagner <sebix@sebix.at>
- Update to version 0.7.11:
  - Add testcase for wildcard match.
  - Update test data and readme link.
  - Fixes issue #19
  - Update PSL.
- Update to version 0.7.10:
  - Update PSL.
- Update to version 0.7.9:
  - Update PSL.
* Sun May 30 2021 Sebastian Wagner <sebix@sebix.at>
- update to version 0.7.8:
  - Update PSL
* Thu May 27 2021 pgajdos@suse.com
- version update to 0.7.7
  * PSL updates
* Thu Nov 19 2020 John Vandenberg <jayvdb@gmail.com>
- Remove tests from runtime package
- Update to v0.7.3-5
  * PSL updates
* Wed Jun  3 2020 Sebastian Wagner <sebix@sebix.at>
- Update to version 0.7.2:
  * Fix PSL file timestamp offset caused by TZ.
- Update to version 0.7.1:
  * Update PSL.
- Update to version 0.7.0:
  * Drop Python 2.5 support.
  * Use file context managers.
- Update to version to 0.6.15:
  * Update PSL.
- Update to version 0.6.14:
  * Use privatesuffix instead of its alias.
  * Fix typo.
* Thu Mar 19 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.6.13
  * no changelog found
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.6.11:
  * no upstream changelog
* Tue Jul 23 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.6.9:
  * no upstream changelog
* Mon May 20 2019 pgajdos@suse.com
- version update to 0.6.7
  * no upstream changelog
* Sat Mar 16 2019 Sebastian Wagner <sebix@sebix.at>
- Update to version 0.6.5:
  * No changes
- Update to version 0.6.4:
  * No changes
* Tue Jan 15 2019 Sebastian Wagner <sebix@sebix.at>
- Update to version 0.6.3:
  * No changes
- Update to version 0.6.2:
  * No changes
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon May 21 2018 sebix@sebix.at
- update to version 0.6.1:
  - cleanup pypi descriptors
- update to version 0.6.0:
  - support for icann-only suffixes
* Mon May 14 2018 sebix@sebix.at
- add change_psl_location.patch to use list from publicsuffix package.
* Thu Mar 29 2018 sebix@sebix.at
- initial package for version 0.5.0
